Easymode : toolkit for making xml based flash websites
======================================================

Easymode is an aspect oriented toolkit that helps making xml based flash websites easy.
The tools included in the toolkit to help you make these kind of sites include:

- Internationalization of models, with admin support.
- Translation of model data using gettext.
- Automatic generation of xml from model trees using xslt.
- Admin support for model trees with more than 2 levels of related items.
- Basic approval support for models.

Documentation
-------------

To build the documentation:

- make sure the requirements are installed ``pip install -r requirements.txt``
- cd to ``docs``
- type: ``make html``
- now your documentation is in: ``docs/_build/html/``

To view the documentation:

go to [easymode docs](http://packages.python.org/django-easymode/)
